@@ -1,7 +1,6 @@
 """Config helper."""
 
 import os
-import re
 from pathlib import Path
 from typing import Any, Dict, Optional, Union, cast
 
@@ -12,59 +11,6 @@ ValidConfigType = Union[str, int, float, bool]
 ConfigDict = Dict[str, ValidConfigType]
 
 
-class FeatureException(Exception):
-    ...
-
-
-_feature_pattern = r'^[a-z]+(_?[a-z]+_?[a-z])*$'
-_feature_prefix = 'WITH_FEAT_'
-
-
-def is_valid_feature_name(feature: str):
-    return all(re.match(_feature_pattern, part) is not None for part in feature.split('.'))
-
-
-def feature_to_config_key(feature: str) -> str:
-    return f'{_feature_prefix}{feature.upper()}'
-
-
-def str2bool(v):
-    return str(v).lower() in {'yes', 'y', 'true', 't', '1'}
-
-
-class FeatureSet:
-    def __init__(self, config: Optional['Config'] = None):
-        if not config:
-            config = Config()
-
-        self.config = config
-        self._features = set()
-        self._feature_defaults = {}
-
-    def register_feature(self, feature: str, default: bool = False):
-        if not is_valid_feature_name(feature):
-            raise FeatureException(f'Invalid feature name: {feature}')
-
-        if feature in self._features:
-            raise FeatureException(f'Duplicate feature: {feature}')
-
-        self._features.add(feature)
-        self._feature_defaults[feature] = default
-
-    def is_active(self, feature: str) -> bool:
-        if feature not in self._features:
-            raise FeatureException(f'Unknown feature: {feature}')
-
-        try:
-            feature_key = feature_to_config_key(feature)
-            value = self.config.get(feature_key)
-            return str2bool(value) if isinstance(value, str) else value
-        except KeyError:
-            ...
-
-        return self._feature_defaults[feature]
-
-
 class Config:  # pragma: only-covered-in-unit-tests
     """This class helps with retrieving config values from a project environment.
 
@@ -125,9 +71,8 @@ class Config:  # pragma: only-covered-in-unit-tests
         self.config = None
         self.aliases = aliases
         self.defaults = (defaults or {}).copy()
-        self.feature_set = FeatureSet(self)
 
-    def get(self, key: str) -> ValidConfigType:
+    def get(self, key: str, default: Optional[ValidConfigType] = None) -> ValidConfigType:
         if key in os.environ:
             return cast(str, os.environ.get(key))
 
@@ -137,7 +82,12 @@ class Config:  # pragma: only-covered-in-unit-tests
             if key in self.config:
                 return self.config[key]  # noqa: WPS529
 
-        return self.defaults[key]
+        try:
+            return self.defaults[key]
+        except KeyError as exc:
+            if default:
+                return default
+            raise exc
 
     @classmethod
     def get_config(cls, path: ValidPath, aliases: Dict[str, str] = None) -> Dict[str, ValidConfigType]:
